@@ -18,11 +18,11 @@ class Schema(DesignationsObject):
              if self.value is a list it will return a list of SchemaNode objects.
         """
         if isinstance(self.value, dict):
-            nodes = SchemaNode(self.get_value('id')).get(parameters={'depth':depth})
+            nodes = SchemaNode(self.get_value('id')).get(parameters=[('depth', depth)])
         
         elif isinstance(self.value, list):
             nodes = [
-                SchemaNode(schema_id).get(parameters={'depth':depth})
+                SchemaNode(schema_id).get(parameters=[('depth', depth)])
                 for schema_id
                 in self.get_value('id')
             ]
