@@ -488,12 +488,10 @@ class Object:
         __str__ is used to represent the object as a string.
         """
 
-        s = (
-            f'{str(self.__class__).split()[1][1:-2].rsplit(".", 1)[0]}\n'
-            f'Length: {len(self)}'
-        )
-        return s
+        return str(self.value)
 
+    def __repr__(self):
+        return str(self)
 
     def __len__(self):
         """
